"""
.. module:: gitdiscribe
   :platform: Unix, Windows
   :synopsis: A useful module indeed.

.. moduleauthor:: Andrew Carter <andrew@invalid.com>


"""

from .gitdiscribe import Gitdiscribe
